@@ -1,3 +1,51 @@
+def splitPdfAllPages(pdfFile):
+    from PyPDF2 import PdfFileReader, PdfFileWriter, PdfFileMerger
+    import os
+    f_name, f_ext=os.path.splitext(pdfFile)
+
+    with open(pdfFile, 'rb') as infile:
+        reader = PdfFileReader(infile)
+        page = reader.numPages
+        for i in range(page):
+            writerStart = PdfFileWriter()
+            writerStart.addPage(reader.getPage(i))
+            fpage=f_name+str(i+1)+f_ext
+            print(fpage)
+            with open(fpage, 'wb') as outfileStart:
+                writerStart.write(outfileStart)
+                print(f"Страницу файла сохранил как {fpage}")
+
+def splitPdfTwoPart(pdfFile,numBreak):
+    from PyPDF2 import PdfFileReader, PdfFileWriter, PdfFileMerger
+    if ((not isinstance(numBreak, int)) or (numBreak<1)):
+            raise TypeError("numBreak должно быть целое число не меньше 1")
+            return
+
+    with open(pdfFile, 'rb') as infile:
+        reader = PdfFileReader(infile)
+        page = reader.numPages
+        f_name, f_ext=os.path.splitext(f)
+
+        if (numBreak>page-1):
+            raise TypeError("numBreak должно быть целое число не больше страниц файла")
+            return
+        writerStart = PdfFileWriter()
+        writerEnd = PdfFileWriter()
+        for i in range(numBreak):
+            writerStart.addPage(reader.getPage(i))
+        for i in range(numBreak,page):
+            writerEnd.addPage(reader.getPage(i))
+
+        print(f"Всего страниц в файле {pdfFile} - {page}")
+        print(f"Разбиваю файл после страницы {numBreak}")
+
+        with open('pagesStart.pdf', 'wb') as outfileStart:
+            writerStart.write(outfileStart)
+        with open('pagesEnd.pdf', 'wb') as outfileEnd:
+            writerEnd.write(outfileEnd)
+        print(f"Начало файла сохранил как pagesStart.pdf")
+        print(f"Конец файла сохранил как pagesEnd.pdf")
+
 def insertStrForFilesName(directory,string,afterNumber):
     import os
     import re
